Colour Models
=============

Tristimulus Values, CIE xyY Colourspace and Chromaticity Coordinates
--------------------------------------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_xyY
    xyY_to_XYZ
    XYZ_to_xy
    xy_to_XYZ
    xyY_to_xy
    xy_to_xyY

Common Models
-------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    COLOURSPACE_MODELS

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    Jab_to_JCh
    JCh_to_Jab
    XYZ_to_Iab
    Iab_to_XYZ

CIE L*a*b* Colourspace
----------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Lab
    Lab_to_XYZ

CIE L*u*v* Colourspace
----------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Luv
    Luv_to_XYZ
    Luv_to_uv
    uv_to_Luv
    Luv_uv_to_xy
    xy_to_Luv_uv
    XYZ_to_CIE1976UCS
    CIE1976UCS_to_XYZ

CIE 1960 UCS Colourspace
------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_UCS
    UCS_to_XYZ
    UCS_to_uv
    uv_to_UCS
    UCS_uv_to_xy
    xy_to_UCS_uv
    XYZ_to_CIE1960UCS
    CIE1960UCS_to_XYZ

CIE 1964 U*V*W* Colourspace
---------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_UVW
    UVW_to_XYZ

Hunter L,a,b Colour Scale
-------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Hunter_Lab
    Hunter_Lab_to_XYZ
    XYZ_to_K_ab_HunterLab1966

Hunter Rd,a,b Colour Scale
--------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Hunter_Rdab
    Hunter_Rdab_to_XYZ

DIN99 Colourspace and DIN99b, DIN99c, DIN99d Refined Formulas
-------------------------------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    Lab_to_DIN99
    DIN99_to_Lab
    XYZ_to_DIN99
    DIN99_to_XYZ

CAM02-LCD, CAM02-SCD, and CAM02-UCS Colourspaces - Luo, Cui and Li (2006)
-------------------------------------------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    JMh_CIECAM02_to_CAM02LCD
    CAM02LCD_to_JMh_CIECAM02
    JMh_CIECAM02_to_CAM02SCD
    CAM02SCD_to_JMh_CIECAM02
    JMh_CIECAM02_to_CAM02UCS
    CAM02UCS_to_JMh_CIECAM02
    XYZ_to_CAM02LCD
    CAM02LCD_to_XYZ
    XYZ_to_CAM02SCD
    CAM02SCD_to_XYZ
    XYZ_to_CAM02UCS
    CAM02UCS_to_XYZ

CAM16-LCD, CAM16-SCD, and CAM16-UCS Colourspaces - Li et al. (2017)
-------------------------------------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    JMh_CAM16_to_CAM16LCD
    CAM16LCD_to_JMh_CAM16
    JMh_CAM16_to_CAM16SCD
    CAM16SCD_to_JMh_CAM16
    JMh_CAM16_to_CAM16UCS
    CAM16UCS_to_JMh_CAM16
    XYZ_to_CAM16LCD
    CAM16LCD_to_XYZ
    XYZ_to_CAM16SCD
    CAM16SCD_to_XYZ
    XYZ_to_CAM16UCS
    CAM16UCS_to_XYZ

:math:`IC_AC_B` Colourspace
---------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_ICaCb
    ICaCb_to_XYZ

:math:`I_GP_GT_G` Colourspace
-----------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_IgPgTg
    IgPgTg_to_XYZ

IPT Colourspace
---------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_IPT
    IPT_to_XYZ
    IPT_hue_angle

Ragoo and Farup (2021) Optimised IPT Colourspace
------------------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_IPT_Ragoo2021
    IPT_Ragoo2021_to_XYZ

hdr-CIELAB Colourspace
----------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_hdr_CIELab
    hdr_CIELab_to_XYZ
    HDR_CIELAB_METHODS

hdr-IPT Colourspace
-------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_hdr_IPT
    hdr_IPT_to_XYZ
    HDR_IPT_METHODS

Oklab Colourspace
-----------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Oklab
    Oklab_to_XYZ

OSA UCS Colourspace
-------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_OSA_UCS
    OSA_UCS_to_XYZ

ProLab Colourspace
------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_ProLab
    ProLab_to_XYZ

Yrg Colourspace - Kirk (2019)
-----------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Yrg
    Yrg_to_XYZ

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    LMS_to_Yrg
    Yrg_to_LMS

:math:`Jzazbz` Colourspace
--------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Jzazbz
    Jzazbz_to_XYZ

**Ancillary Objects**

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    IZAZBZ_METHODS
    XYZ_to_Izazbz
    Izazbz_to_XYZ

Polar Conversions
-----------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    COLOURSPACE_MODELS_POLAR_CONVERSIONS
    Lab_to_LCHab
    LCHab_to_Lab
    Luv_to_LCHuv
    LCHuv_to_Luv
    hdr_CIELab_to_hdr_CIELCHab
    hdr_CIELCHab_to_hdr_CIELab
    Hunter_Lab_to_Hunter_LCHab
    Hunter_LCHab_to_Hunter_Lab
    Hunter_Rdab_to_Hunter_RdCHab
    Hunter_RdCHab_to_Hunter_Rdab
    ICaCb_to_ICHab
    ICHab_to_ICaCb
    ICtCp_to_ICHtp
    ICHtp_to_ICtCp
    IgPgTg_to_IgCHpt
    IgCHpt_to_IgPgTg
    IPT_to_ICH
    ICH_to_IPT
    Izazbz_to_IzCHab
    IzCHab_to_Izazbz
    Jzazbz_to_JzCHab
    JzCHab_to_Jzazbz
    hdr_IPT_to_hdr_ICH
    hdr_ICH_to_hdr_IPT
    Oklab_to_Oklch
    Oklch_to_Oklab
    ProLab_to_ProLCHab
    ProLCHab_to_ProLab
    IPT_Ragoo2021_to_ICH_Ragoo2021
    ICH_Ragoo2021_to_IPT_Ragoo2021

RGB Colourspace and Transformations
-----------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_RGB
    RGB_to_XYZ
    RGB_to_RGB
    matrix_RGB_to_RGB

**Ancillary Objects**

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_sRGB
    sRGB_to_XYZ

RGB Colourspace Derivation
~~~~~~~~~~~~~~~~~~~~~~~~~~
``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    normalised_primary_matrix
    chromatically_adapted_primaries
    primaries_whitepoint
    RGB_luminance
    RGB_luminance_equation

RGB Colourspaces
~~~~~~~~~~~~~~~~

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/
    :template: class.rst

    RGB_Colourspace

.. autosummary::
    :toctree: generated/

    RGB_COLOURSPACES

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    RGB_COLOURSPACE_ACES2065_1
    RGB_COLOURSPACE_ACESCC
    RGB_COLOURSPACE_ACESCCT
    RGB_COLOURSPACE_ACESPROXY
    RGB_COLOURSPACE_ACESCG
    RGB_COLOURSPACE_ADOBE_RGB1998
    RGB_COLOURSPACE_ADOBE_WIDE_GAMUT_RGB
    RGB_COLOURSPACE_ARRI_WIDE_GAMUT_3
    RGB_COLOURSPACE_ARRI_WIDE_GAMUT_4
    RGB_COLOURSPACE_APPLE_RGB
    RGB_COLOURSPACE_BEST_RGB
    RGB_COLOURSPACE_BETA_RGB
    RGB_COLOURSPACE_BLACKMAGIC_WIDE_GAMUT
    RGB_COLOURSPACE_BT470_525
    RGB_COLOURSPACE_BT470_625
    RGB_COLOURSPACE_BT709
    RGB_COLOURSPACE_BT2020
    RGB_COLOURSPACE_CIE_RGB
    RGB_COLOURSPACE_CINEMA_GAMUT
    RGB_COLOURSPACE_COLOR_MATCH_RGB
    RGB_COLOURSPACE_DAVINCI_WIDE_GAMUT
    RGB_COLOURSPACE_DCDM_XYZ
    RGB_COLOURSPACE_DCI_P3
    RGB_COLOURSPACE_DCI_P3_P
    RGB_COLOURSPACE_DISPLAY_P3
    RGB_COLOURSPACE_DJI_D_GAMUT
    RGB_COLOURSPACE_DON_RGB_4
    RGB_COLOURSPACE_EBU_3213_E
    RGB_COLOURSPACE_ECI_RGB_V2
    RGB_COLOURSPACE_EKTA_SPACE_PS_5
    RGB_COLOURSPACE_F_GAMUT
    RGB_COLOURSPACE_FILMLIGHT_E_GAMUT
    RGB_COLOURSPACE_H273_GENERIC_FILM
    RGB_COLOURSPACE_H273_22_UNSPECIFIED
    RGB_COLOURSPACE_PROTUNE_NATIVE
    RGB_COLOURSPACE_MAX_RGB
    RGB_COLOURSPACE_N_GAMUT
    RGB_COLOURSPACE_NTSC1953
    RGB_COLOURSPACE_NTSC1987
    RGB_COLOURSPACE_P3_D65
    RGB_COLOURSPACE_PAL_SECAM
    RGB_COLOURSPACE_RED_COLOR
    RGB_COLOURSPACE_RED_COLOR_2
    RGB_COLOURSPACE_RED_COLOR_3
    RGB_COLOURSPACE_RED_COLOR_4
    RGB_COLOURSPACE_RED_WIDE_GAMUT_RGB
    RGB_COLOURSPACE_DRAGON_COLOR
    RGB_COLOURSPACE_DRAGON_COLOR_2
    RGB_COLOURSPACE_ROMM_RGB
    RGB_COLOURSPACE_RIMM_RGB
    RGB_COLOURSPACE_ERIMM_RGB
    RGB_COLOURSPACE_PROPHOTO_RGB
    RGB_COLOURSPACE_PLASA_ANSI_E154
    RGB_COLOURSPACE_RUSSELL_RGB
    RGB_COLOURSPACE_SHARP_RGB
    RGB_COLOURSPACE_SMPTE_240M
    RGB_COLOURSPACE_SMPTE_C
    RGB_COLOURSPACE_S_GAMUT
    RGB_COLOURSPACE_S_GAMUT3
    RGB_COLOURSPACE_S_GAMUT3_CINE
    RGB_COLOURSPACE_VENICE_S_GAMUT3
    RGB_COLOURSPACE_VENICE_S_GAMUT3_CINE
    RGB_COLOURSPACE_sRGB
    RGB_COLOURSPACE_V_GAMUT
    RGB_COLOURSPACE_XTREME_RGB

Colour Component Transfer Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    cctf_encoding
    CCTF_ENCODINGS
    cctf_decoding
    CCTF_DECODINGS
    gamma_function
    linear_function

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    cctf_encoding_ROMMRGB
    cctf_decoding_ROMMRGB
    cctf_encoding_RIMMRGB
    cctf_decoding_RIMMRGB

**Aliases**

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    cctf_encoding_ProPhotoRGB
    cctf_decoding_ProPhotoRGB

**Ancillary Objects**

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    exponent_function_basic
    exponent_function_monitor_curve
    logarithmic_function_basic
    logarithmic_function_quasilog
    logarithmic_function_camera

Opto-Electronic Transfer Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    oetf
    OETFS
    oetf_inverse
    OETF_INVERSES

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    oetf_ARIBSTDB67
    oetf_inverse_ARIBSTDB67
    oetf_BlackmagicFilmGeneration5
    oetf_inverse_BlackmagicFilmGeneration5
    oetf_DaVinciIntermediate
    oetf_inverse_DaVinciIntermediate
    oetf_BT2020
    oetf_inverse_BT2020
    oetf_BT2100_HLG
    oetf_inverse_BT2100_HLG
    oetf_BT2100_PQ
    oetf_inverse_BT2100_PQ
    oetf_BT601
    oetf_inverse_BT601
    oetf_BT709
    oetf_inverse_BT709
    oetf_H273_Log
    oetf_inverse_H273_Log
    oetf_H273_LogSqrt
    oetf_inverse_H273_LogSqrt
    oetf_H273_IEC61966_2
    oetf_inverse_H273_IEC61966_2
    oetf_SMPTE240M

Electro-Optical Transfer Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    eotf
    EOTFS
    eotf_inverse
    EOTF_INVERSES

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    eotf_DCDM
    eotf_inverse_DCDM
    eotf_DICOMGSDF
    eotf_inverse_DICOMGSDF
    eotf_BT1886
    eotf_inverse_BT1886
    BT2100_HLG_EOTF_METHODS
    eotf_BT2100_HLG
    BT2100_HLG_EOTF_INVERSE_METHODS
    eotf_inverse_BT2100_HLG
    eotf_BT2100_PQ
    eotf_inverse_BT2100_PQ
    eotf_H273_ST428_1
    eotf_inverse_H273_ST428_1
    eotf_SMPTE240M
    eotf_ST2084
    eotf_inverse_ST2084
    eotf_sRGB
    eotf_inverse_sRGB

Opto-Optical Transfer Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    ootf
    OOTFS
    ootf_inverse
    OOTF_INVERSES


``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    BT2100_HLG_OOTF_METHODS
    ootf_BT2100_HLG
    BT2100_HLG_OOTF_INVERSE_METHODS
    ootf_inverse_BT2100_HLG
    ootf_BT2100_PQ
    ootf_inverse_BT2100_PQ

Log Encoding and Decoding
~~~~~~~~~~~~~~~~~~~~~~~~~

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    log_encoding
    LOG_ENCODINGS
    log_decoding
    LOG_DECODINGS

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    log_encoding_ACEScc
    log_decoding_ACEScc
    log_encoding_ACEScct
    log_decoding_ACEScct
    log_encoding_ACESproxy
    log_decoding_ACESproxy
    log_encoding_AppleLogProfile
    log_decoding_AppleLogProfile
    log_encoding_ARRILogC3
    log_decoding_ARRILogC3
    log_encoding_CanonLog2
    log_decoding_CanonLog2
    log_encoding_CanonLog3
    log_decoding_CanonLog3
    log_encoding_CanonLog
    log_decoding_CanonLog
    log_encoding_Cineon
    log_decoding_Cineon
    log_encoding_ERIMMRGB
    log_decoding_ERIMMRGB
    log_encoding_FLog
    log_decoding_FLog
    log_encoding_FLog2
    log_decoding_FLog2
    log_encoding_LLog
    log_decoding_LLog
    log_encoding_Log2
    log_decoding_Log2
    LOG3G10_ENCODING_METHODS
    log_encoding_Log3G10
    LOG3G10_DECODING_METHODS
    log_decoding_Log3G10
    log_encoding_Log3G12
    log_decoding_Log3G12
    log_encoding_NLog
    log_decoding_NLog
    log_encoding_Panalog
    log_decoding_Panalog
    log_encoding_PivotedLog
    log_decoding_PivotedLog
    log_encoding_Protune
    log_decoding_Protune
    log_encoding_REDLog
    log_decoding_REDLog
    log_encoding_REDLogFilm
    log_decoding_REDLogFilm
    log_encoding_SLog
    log_decoding_SLog
    log_encoding_SLog2
    log_decoding_SLog2
    log_encoding_SLog3
    log_decoding_SLog3
    log_encoding_VLog
    log_decoding_VLog
    log_encoding_ViperLog
    log_decoding_ViperLog

Colour Encodings
~~~~~~~~~~~~~~~~

Y'CbCr Colour Encoding
^^^^^^^^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    WEIGHTS_YCBCR
    matrix_YCbCr
    offset_YCbCr
    RGB_to_YCbCr
    YCbCr_to_RGB
    RGB_to_YcCbcCrc
    YcCbcCrc_to_RGB

**Ancillary Objects**

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    full_to_legal
    legal_to_full
    CV_range

YCoCg Colour Encoding
^^^^^^^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_to_YCoCg
    YCoCg_to_RGB

:math:`IC_TC_P` Colour Encoding
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_to_ICtCp
    ICtCp_to_RGB
    XYZ_to_ICtCp
    ICtCp_to_XYZ

RGB Representations
~~~~~~~~~~~~~~~~~~~

Prismatic Colourspace
^^^^^^^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_to_Prismatic
    Prismatic_to_RGB

HSV Colourspace
^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_to_HSV
    HSV_to_RGB

HSL Colourspace
^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_to_HSL
    HSL_to_RGB

HCL Colourspace
^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_to_HCL
    HCL_to_RGB

CMY Colourspace
^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_to_CMY
    CMY_to_RGB
    CMY_to_CMYK
    CMYK_to_CMY

IHLS - Hanbury (2003)
^^^^^^^^^^^^^^^^^^^^^

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_to_IHLS
    IHLS_to_RGB

Recommendation ITU-T H.273 Code points for Video Signal Type Identification
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    COLOUR_PRIMARIES_ITUTH273
    TRANSFER_CHARACTERISTICS_ITUTH273
    MATRIX_COEFFICIENTS_ITUTH273

**Ancillary Objects**

``colour.models``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    describe_video_signal_colour_primaries
    describe_video_signal_transfer_characteristics
    describe_video_signal_matrix_coefficients

Pointer's Gamut
---------------

``colour``

.. currentmodule:: colour.models

.. autosummary::
    :toctree: generated/

    CCS_ILLUMINANT_POINTER_GAMUT
    DATA_POINTER_GAMUT_VOLUME
    CCS_POINTER_GAMUT_BOUNDARY
